@@ -227,6 +227,7 @@ module NATS
       opts[:pedantic] = false if opts[:pedantic].nil?
       opts[:reconnect] = true if opts[:reconnect].nil?
       opts[:old_style_request] = false if opts[:old_style_request].nil?
+      opts[:ignore_discovered_urls] = false if opts[:ignore_discovered_urls].nil?
       opts[:reconnect_time_wait] = NATS::IO::RECONNECT_TIME_WAIT if opts[:reconnect_time_wait].nil?
       opts[:max_reconnect_attempts] = NATS::IO::MAX_RECONNECT_ATTEMPTS if opts[:max_reconnect_attempts].nil?
       opts[:ping_interval] = NATS::IO::DEFAULT_PING_INTERVAL if opts[:ping_interval].nil?
@@ -237,6 +238,7 @@ module NATS
       opts[:pedantic] = ENV['NATS_PEDANTIC'].downcase == 'true' unless ENV['NATS_PEDANTIC'].nil?
       opts[:reconnect] = ENV['NATS_RECONNECT'].downcase == 'true' unless ENV['NATS_RECONNECT'].nil?
       opts[:reconnect_time_wait] = ENV['NATS_RECONNECT_TIME_WAIT'].to_i unless ENV['NATS_RECONNECT_TIME_WAIT'].nil?
+      opts[:ignore_discovered_urls] = ENV['NATS_IGNORE_DISCOVERED_URLS'].downcase == 'true' unless ENV['NATS_IGNORE_DISCOVERED_URLS'].nil?
       opts[:max_reconnect_attempts] = ENV['NATS_MAX_RECONNECT_ATTEMPTS'].to_i unless ENV['NATS_MAX_RECONNECT_ATTEMPTS'].nil?
       opts[:ping_interval] = ENV['NATS_PING_INTERVAL'].to_i unless ENV['NATS_PING_INTERVAL'].nil?
       opts[:max_outstanding_pings] = ENV['NATS_MAX_OUTSTANDING_PINGS'].to_i unless ENV['NATS_MAX_OUTSTANDING_PINGS'].nil?
@@ -256,7 +258,7 @@ module NATS
                    end
         @server_pool << {
           :uri => nats_uri,
-          :hostname => nats_uri.host
+          :hostname => nats_uri.hostname
         }
       end
 
@@ -807,17 +809,17 @@ module NATS
 
         # Detect any announced server that we might not be aware of...
         connect_urls = @server_info[:connect_urls]
-        if connect_urls
+        if !@options[:ignore_discovered_urls] && connect_urls
           srvs = []
           connect_urls.each do |url|
             scheme = client_using_secure_connection? ? "tls" : "nats"
             u = URI.parse("#{scheme}://#{url}")
 
             # Skip in case it is the current server which we already know
-            next if @uri.host == u.host && @uri.port == u.port
+            next if @uri.hostname == u.hostname && @uri.port == u.port
 
             present = server_pool.detect do |srv|
-              srv[:uri].host == u.host && srv[:uri].port == u.port
+              srv[:uri].hostname == u.hostname && srv[:uri].port == u.port
             end
 
             if not present
@@ -832,7 +834,7 @@ module NATS
               end
 
               # NOTE: Auto discovery won't work here when TLS host verification is enabled.
-              srv = { :uri => u, :reconnect_attempts => 0, :discovered => true, :hostname => u.host }
+              srv = { :uri => u, :reconnect_attempts => 0, :discovered => true, :hostname => u.hostname }
               srvs << srv
             end
           end
@@ -1758,34 +1760,20 @@ module NATS
     end
 
     def process_uri(uris)
-      connect_uris = []
-      uris.split(',').each do |uri|
+      uris.split(',').map do |uri|
         opts = {}
 
         # Scheme
-        if uri.include?("://")
-          scheme, uri = uri.split("://")
-          opts[:scheme] = scheme
-        else
-          opts[:scheme] = 'nats'
-        end
+        uri = "nats://#{uri}" if !uri.include?("://")
 
-        # UserInfo
-        if uri.include?("@")
-          userinfo, endpoint = uri.split("@")
-          host, port = endpoint.split(":")
-          opts[:userinfo] = userinfo
-        else
-          host, port = uri.split(":")
-        end
+        uri_object = URI(uri)
 
         # Host and Port
-        opts[:host] = host || "localhost"
-        opts[:port] = port || DEFAULT_PORT
+        uri_object.hostname ||= "localhost"
+        uri_object.port ||= DEFAULT_PORT
 
-        connect_uris << URI::Generic.build(opts)
+        uri_object
       end
-      connect_uris
     end
   end
 
@@ -1834,7 +1822,7 @@ module NATS
       end
 
       def connect
-        addrinfo = ::Socket.getaddrinfo(@uri.host, nil, ::Socket::AF_UNSPEC, ::Socket::SOCK_STREAM)
+        addrinfo = ::Socket.getaddrinfo(@uri.hostname, nil, ::Socket::AF_UNSPEC, ::Socket::SOCK_STREAM)
         addrinfo.each_with_index do |ai, i|
           begin
             @socket = connect_addrinfo(ai, @uri.port, @connect_timeout)
